==> qtjambi-datavisualization-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDataVisualization/QItemModelScatterDataProxy_shell.h <==
#ifndef QITEMMODELSCATTERDATAPROXY_SHELL_H
#define QITEMMODELSCATTERDATAPROXY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qitemmodelscatterdataproxy.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/qabstractdataproxy.h>
#include <QtDataVisualization/qscatter3dseries.h>
#include <QtDataVisualization/qscatterdataitem.h>
#include <QtDataVisualization/qscatterdataproxy.h>
#include <QtJambi/RegistryAPI>


class QItemModelScatterDataProxy_shell : public QtDataVisualization::QItemModelScatterDataProxy, public QtJambiShellInterface
{
public:
    QItemModelScatterDataProxy_shell(QAbstractItemModel* itemModel0, QObject* parent1 = nullptr);
    QItemModelScatterDataProxy_shell(QAbstractItemModel* itemModel0, const QString& xPosRole1, const QString& yPosRole2, const QString& zPosRole3, QObject* parent4 = nullptr);
    QItemModelScatterDataProxy_shell(QAbstractItemModel* itemModel0, const QString& xPosRole1, const QString& yPosRole2, const QString& zPosRole3, const QString& rotationRole4, QObject* parent5 = nullptr);
    QItemModelScatterDataProxy_shell(QObject* parent0 = nullptr);
    ~QItemModelScatterDataProxy_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QItemModelScatterDataProxy_access : public QtDataVisualization::QItemModelScatterDataProxy
{
};

#endif // QITEMMODELSCATTERDATAPROXY_SHELL_H

==> qtjambi-datavisualization-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiDataVisualization/QItemModelScatterDataProxy_shell.h <==
#ifndef QITEMMODELSCATTERDATAPROXY_SHELL_H
#define QITEMMODELSCATTERDATAPROXY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qitemmodelscatterdataproxy.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/qabstractdataproxy.h>
#include <QtDataVisualization/qscatter3dseries.h>
#include <QtDataVisualization/qscatterdataitem.h>
#include <QtDataVisualization/qscatterdataproxy.h>
#include <QtJambi/RegistryAPI>


class QItemModelScatterDataProxy_shell : public QItemModelScatterDataProxy, public QtJambiShellInterface
{
public:
    QItemModelScatterDataProxy_shell(QAbstractItemModel* itemModel0, QObject* parent1 = nullptr);
    QItemModelScatterDataProxy_shell(QAbstractItemModel* itemModel0, const QString& xPosRole1, const QString& yPosRole2, const QString& zPosRole3, QObject* parent4 = nullptr);
    QItemModelScatterDataProxy_shell(QAbstractItemModel* itemModel0, const QString& xPosRole1, const QString& yPosRole2, const QString& zPosRole3, const QString& rotationRole4, QObject* parent5 = nullptr);
    QItemModelScatterDataProxy_shell(QObject* parent0 = nullptr);
    ~QItemModelScatterDataProxy_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QItemModelScatterDataProxy_access : public QItemModelScatterDataProxy
{
};

#endif // QITEMMODELSCATTERDATAPROXY_SHELL_H
